@@ -6,6 +6,8 @@ from django.contrib.contenttypes.models import ContentType
 from django.db.models import Manager
 from django.db import models
 from django.db.models.query import QuerySet
+from django.db.models import F
+from django.db.models.functions import Upper
 from django.contrib.contenttypes.fields import GenericForeignKey, GenericRelation
 
 from polymorphic.managers import PolymorphicManager
@@ -1000,3 +1002,93 @@ class Book(PolymorphicModel):
 
 class SpecialBook(Book):
     pass
+
+
+class FilteredManager(PolymorphicManager):
+    def get_queryset(self):
+        return super().get_queryset().exclude(field2=Upper(F("field2")))
+
+
+class Model2BFiltered(Model2B):
+    objects = FilteredManager()
+
+
+class Model2CFiltered(Model2BFiltered):
+    field3 = models.CharField(max_length=30, blank=True, default="")
+
+
+class CustomBaseManager(PolymorphicManager):
+    pass
+
+
+class FilteredManager2(FilteredManager):
+    pass
+
+
+class Model2CNamedManagers(Model2CFiltered):
+    all_objects = CustomBaseManager()
+    filtered_objects = FilteredManager2()
+
+    class Meta:
+        base_manager_name = "all_objects"
+        default_manager_name = "filtered_objects"
+
+
+class Model2CNamedDefault(Model2CFiltered):
+    custom_objects = FilteredManager2()
+
+    class Meta:
+        default_manager_name = "custom_objects"
+
+
+# serialization natural key tests #517
+class NatKeyManager(PolymorphicManager):
+    def get_by_natural_key(self, slug):
+        return self.get(slug=slug)
+
+
+class NatKeyParent(PolymorphicModel):
+    slug = models.SlugField(unique=True)
+    content = models.CharField(blank=True, max_length=100)
+
+    objects = NatKeyManager()
+
+    def natural_key(self):
+        return (self.slug,)
+
+
+class NatKeyChild(NatKeyParent):
+    foo = models.OneToOneField(NatKeyParent, models.CASCADE, parent_link=True, primary_key=True)
+    val = models.IntegerField(default=0)
+
+    def natural_key(self):
+        return self.foo.natural_key()
+
+    natural_key.dependencies = ["tests.natkeyparent"]
+
+
+class ManagerTest(PolymorphicModel):
+    name = models.CharField(max_length=30)
+
+    objects = CustomBaseManager()
+
+    class Meta:
+        base_manager_name = "objects"
+
+
+class ManagerTestChild(ManagerTest):
+    pass
+
+
+class PlainManager(models.Manager): ...
+
+
+class ManagerTestPlain(models.Model):
+    objects = PlainManager()
+
+    class Meta:
+        base_manager_name = "objects"
+
+
+class ManagerTestChildPlain(ManagerTestPlain):
+    pass
